drop database LearningInternals
go

create database LearningInternals
go

use LearningInternals
go

-- Understanding Heap

drop table Employee
go

create table Employee(
intEmpId int identity(10001,1),
strFirstName varchar(100),
strLastName varchar(100),
strDeptId varchar(6),
strSSNId int)
go

set nocount on
go
insert into employee(strFirstName, strLastName, strDeptId, strSSNId) values ('AAA','AAA','DEPT01',round(rand()*1000000,0))
go 10000


-- see the execution plan and observe the operator
select * from Employee where intEmpId = 10010


-- extent allocation info
DBCC TRACEON(3604)
DBCC EXTENTINFO('LearningInternals', 'employee')
DBCC TRACEOFF(3604)

-- pages allocated for a table

-- DBCC IND ( { 'dbname' | dbid }, { 'objname' | objid },  { nonclustered indid | 1 | 0 | -1 | -2 } [, partition_number] )

DBCC TRACEON(3604)
DBCC IND('LearningInternals', 'employee', -1)
DBCC TRACEOFF(3604)

DBCC TRACEON(3604)
DBCC PAGE(LearningInternals, 1, 169, 3)-- WITH TABLERESULTS
DBCC TRACEOFF(3604)

-- Understanding NonClustered Index refering Heap

Create NonClustered index NCI_employee_intEmpId on employee(intEmpId)
GO


-- see the execution plan and observe the operator
select * from Employee

-- see the execution plan and observe the operator
select * from Employee where intEmpId = 10100

-- see the execution plan and observe the operator
select intEmpId from Employee

-- extent allocation info
DBCC TRACEON(3604)
DBCC EXTENTINFO('LearningInternals', 'employee')
DBCC TRACEOFF(3604)

-- pages allocated for a table
DBCC TRACEON(3604)
DBCC IND('LearningInternals', 'employee', -1)
DBCC TRACEOFF(3604)

DBCC TRACEON(3604)
DBCC PAGE(LearningInternals, 1, 173, 3)-- WITH TABLERESULTS
DBCC TRACEOFF(3604)



-- Understanding Clustered Index

drop table Employee
go

create table Employee(
intEmpId int identity(10001,1) primary key,
strFirstName varchar(100),
strLastName varchar(100),
strDeptId varchar(6),
strSSNId int)
go

set nocount on
go
insert into employee(strFirstName, strLastName, strDeptId, strSSNId) values ('AAA','AAA','DEPT01',round(rand()*1000000,0))
go 10000


-- see the execution plan and observe the operator
select * from Employee

-- see the execution plan and observe the operator
select * from Employee where intEmpId = 10100


-- extent allocation info
DBCC TRACEON(3604)
DBCC EXTENTINFO('LearningInternals', 'employee')
DBCC TRACEOFF(3604)

-- pages allocated for a table
DBCC TRACEON(3604)
DBCC IND('LearningInternals', 'employee', -1)
DBCC TRACEOFF(3604)

DBCC TRACEON(3604)
DBCC PAGE(LearningInternals, 1, 147, 3)-- WITH TABLERESULTS
DBCC TRACEOFF(3604)

-- Understanding NonClustered Index refering Clustered Index

Create NonClustered index NCI_employee_intEmpId on employee(strSSNId)
GO

select top 100 * from employee

-- see the execution plan and observe the operator
select * from Employee where strSSNId = 863895

-- extent allocation info
DBCC TRACEON(3604)
DBCC EXTENTINFO('LearningInternals', 'employee')
DBCC TRACEOFF(3604)

-- pages allocated for a table
DBCC TRACEON(3604)
DBCC IND('LearningInternals', 'employee', -1)
DBCC TRACEOFF(3604)


DBCC TRACEON(3604)
DBCC PAGE(LearningInternals, 1, 172, 3)-- WITH TABLERESULTS
DBCC TRACEOFF(3604)

